[][src]Struct mini_haskell::rc_view::RcView

pub struct RcView<T: ?Sized, U: ?Sized> { /* fields omitted */ }

A view into an Rc.

Implementations

impl<T: ?Sized, U: ?Sized> RcView<T, U>[src]

pub fn new(whole: Rc<T>, to_focus: impl FnOnce(&T) -> &U) -> Self[src]

Create a view into an Rc.

pub unsafe fn wrap(whole: Rc<T>, focus: &U) -> Self[src]

Create a view into an Rc.

Safety

Call on this unsafe functions should take special care so that the provided reference focus is indeed a view into the related Rc.

pub fn map<V: ?Sized>(self, f: impl FnOnce(&U) -> &V) -> RcView<T, V>[src]

Refocus the view.

pub unsafe fn derive<V: ?Sized>(&self, focus: &V) -> RcView<T, V>[src]

Derive an RcView to a new focus from this view.

Safety

Call on this unsafe functions should take special care so that the provided reference focus is indeed a view into the related Rc.

pub unsafe fn derive_take<V: ?Sized>(self, focus: &V) -> RcView<T, V>[src]

Derive an RcView to a new focus from this view. Consumes this view.

Safety

Call on this unsafe functions should take special care so that the provided reference focus is indeed a view into the related Rc.